Evolvable Networks Utils
=======================

Model Compilation
~~~~~~~~~~~~~~~~~

.. autofunction:: agilerl.utils.evolvable_networks.compile_model

Space Utilities
~~~~~~~~~~~~~~~

.. autofunction:: agilerl.utils.evolvable_networks.is_image_space

.. autofunction:: agilerl.utils.evolvable_networks.is_box_space_ndim

.. autofunction:: agilerl.utils.evolvable_networks.is_vector_space

.. autofunction:: agilerl.utils.evolvable_networks.tuple_to_dict_space

.. autofunction:: agilerl.utils.evolvable_networks.tuple_to_dict_obs

Configuration Utilities
~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: agilerl.utils.evolvable_networks.config_from_dict

.. autofunction:: agilerl.utils.evolvable_networks.get_default_encoder_config

Module Inspection
~~~~~~~~~~~~~~~~~

.. autofunction:: agilerl.utils.evolvable_networks.contains_moduledict

.. autofunction:: agilerl.utils.evolvable_networks.get_module_dict

Layer Factory Functions
~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: agilerl.utils.evolvable_networks.get_batch_norm_layer

.. autofunction:: agilerl.utils.evolvable_networks.get_conv_layer

.. autofunction:: agilerl.utils.evolvable_networks.get_normalization

.. autofunction:: agilerl.utils.evolvable_networks.get_activation

.. autofunction:: agilerl.utils.evolvable_networks.get_pooling

Weight Initialization
~~~~~~~~~~~~~~~~~~~~

.. autofunction:: agilerl.utils.evolvable_networks.layer_init

.. autofunction:: agilerl.utils.evolvable_networks.init_weights_gaussian

Network Creation
~~~~~~~~~~~~~~~

.. autofunction:: agilerl.utils.evolvable_networks.create_cnn

.. autofunction:: agilerl.utils.evolvable_networks.create_mlp

.. autofunction:: agilerl.utils.evolvable_networks.create_simba

.. autofunction:: agilerl.utils.evolvable_networks.create_resnet
